# Installation

![](dont_panic.png)


## Requirements

Marvin requires Python 3.10. While nothing in Marvin should prevent use with Python 3.11, some dependencies may not be fully compatible yet.
## For normal use
To install Marvin, run `pip install marvin`. As a matter of best practice, we recommend installing Marvin in a [virtual environment](https://realpython.com/python-virtual-environments-a-primer/).

Before using Marvin, you'll need to [configure your OpenAI API key](openai.md).

## For development

To install Marvin for development, please see the [development guide](../development/development.md).